@@ -16,7 +16,8 @@ class UserAccountRoleServiceApi:
 
         This operation grants the role to the given user with in the given account.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True
+        asynchronous HTTP request, please pass async_req=True.
+        
         >>> thread = api.add_role(user_id, account_id, role_id, async_req=True)
         >>> result = thread.get()
 
@@ -30,8 +31,8 @@ class UserAccountRoleServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
-
-
+        
+        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
         if kwargs.get('async_req'):
             return self.add_role_with_http_info(user_id, account_id, role_id, **kwargs)
         else:
@@ -43,7 +44,8 @@ class UserAccountRoleServiceApi:
 
         This operation grants the role to the given user with in the given account.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True
+        asynchronous HTTP request, please pass async_req=True.
+        
         >>> thread = api.add_role_with_http_info(user_id, account_id, role_id, async_req=True)
         >>> result = thread.get()
 
@@ -61,7 +63,7 @@ class UserAccountRoleServiceApi:
         all_params.append('async_req')
         all_params.append('_return_http_data_only')
         all_params.append('_preload_content')
-        all_params.append('_request_timeout')
+        all_params.append('request_timeout')
 
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -125,7 +127,7 @@ class UserAccountRoleServiceApi:
             async_req=params.get('async_req'),
             _return_http_data_only=params.get('_return_http_data_only'),
             _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('_request_timeout'),
+            _request_timeout=params.get('request_timeout'),
             collection_formats=collection_formats)
 
     def list(self, user_id, account_id, **kwargs):
@@ -133,7 +135,8 @@ class UserAccountRoleServiceApi:
 
         List all the roles that are assigned to the given user in the given account.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True
+        asynchronous HTTP request, please pass async_req=True.
+        
         >>> thread = api.list(user_id, account_id, async_req=True)
         >>> result = thread.get()
 
@@ -145,8 +148,8 @@ class UserAccountRoleServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
-
-
+        
+        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
         if kwargs.get('async_req'):
             return self.list_with_http_info(user_id, account_id, **kwargs)
         else:
@@ -158,7 +161,8 @@ class UserAccountRoleServiceApi:
 
         List all the roles that are assigned to the given user in the given account.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True
+        asynchronous HTTP request, please pass async_req=True.
+        
         >>> thread = api.list_with_http_info(user_id, account_id, async_req=True)
         >>> result = thread.get()
 
@@ -174,7 +178,7 @@ class UserAccountRoleServiceApi:
         all_params.append('async_req')
         all_params.append('_return_http_data_only')
         all_params.append('_preload_content')
-        all_params.append('_request_timeout')
+        all_params.append('request_timeout')
 
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -230,7 +234,7 @@ class UserAccountRoleServiceApi:
             async_req=params.get('async_req'),
             _return_http_data_only=params.get('_return_http_data_only'),
             _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('_request_timeout'),
+            _request_timeout=params.get('request_timeout'),
             collection_formats=collection_formats)
 
     def remove_role(self, id, **kwargs):
@@ -238,7 +242,8 @@ class UserAccountRoleServiceApi:
 
         This operation removes the specified user account role.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True
+        asynchronous HTTP request, please pass async_req=True.
+        
         >>> thread = api.remove_role(id, async_req=True)
         >>> result = thread.get()
 
@@ -249,8 +254,8 @@ class UserAccountRoleServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
-
-
+        
+        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
         if kwargs.get('async_req'):
             return self.remove_role_with_http_info(id, **kwargs)
         else:
@@ -262,7 +267,8 @@ class UserAccountRoleServiceApi:
 
         This operation removes the specified user account role.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True
+        asynchronous HTTP request, please pass async_req=True.
+        
         >>> thread = api.remove_role_with_http_info(id, async_req=True)
         >>> result = thread.get()
 
@@ -277,7 +283,7 @@ class UserAccountRoleServiceApi:
         all_params.append('async_req')
         all_params.append('_return_http_data_only')
         all_params.append('_preload_content')
-        all_params.append('_request_timeout')
+        all_params.append('request_timeout')
 
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -327,5 +333,5 @@ class UserAccountRoleServiceApi:
             async_req=params.get('async_req'),
             _return_http_data_only=params.get('_return_http_data_only'),
             _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('_request_timeout'),
+            _request_timeout=params.get('request_timeout'),
             collection_formats=collection_formats)
