@@ -235,7 +235,7 @@ class DebtCollectionCase:
     def created_on(self):
         """Gets the created_on of this DebtCollectionCase.
 
-            The created on date indicates the date on which the entity was stored into the database.
+            The date and time when the object was created.
 
         :return: The created_on of this DebtCollectionCase.
         :rtype: datetime
@@ -246,7 +246,7 @@ class DebtCollectionCase:
     def created_on(self, created_on):
         """Sets the created_on of this DebtCollectionCase.
 
-            The created on date indicates the date on which the entity was stored into the database.
+            The date and time when the object was created.
 
         :param created_on: The created_on of this DebtCollectionCase.
         :type: datetime
@@ -419,7 +419,7 @@ class DebtCollectionCase:
     def id(self):
         """Gets the id of this DebtCollectionCase.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :return: The id of this DebtCollectionCase.
         :rtype: int
@@ -430,7 +430,7 @@ class DebtCollectionCase:
     def id(self, id):
         """Sets the id of this DebtCollectionCase.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :param id: The id of this DebtCollectionCase.
         :type: int
@@ -511,7 +511,7 @@ class DebtCollectionCase:
     def linked_space_id(self):
         """Gets the linked_space_id of this DebtCollectionCase.
 
-            The linked space id holds the ID of the space to which the entity belongs to.
+            The ID of the space this object belongs to.
 
         :return: The linked_space_id of this DebtCollectionCase.
         :rtype: int
@@ -522,7 +522,7 @@ class DebtCollectionCase:
     def linked_space_id(self, linked_space_id):
         """Sets the linked_space_id of this DebtCollectionCase.
 
-            The linked space id holds the ID of the space to which the entity belongs to.
+            The ID of the space this object belongs to.
 
         :param linked_space_id: The linked_space_id of this DebtCollectionCase.
         :type: int
@@ -557,7 +557,7 @@ class DebtCollectionCase:
     def planned_purge_date(self):
         """Gets the planned_purge_date of this DebtCollectionCase.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :return: The planned_purge_date of this DebtCollectionCase.
         :rtype: datetime
@@ -568,7 +568,7 @@ class DebtCollectionCase:
     def planned_purge_date(self, planned_purge_date):
         """Sets the planned_purge_date of this DebtCollectionCase.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :param planned_purge_date: The planned_purge_date of this DebtCollectionCase.
         :type: datetime
@@ -787,7 +787,7 @@ class DebtCollectionCase:
     def state(self):
         """Gets the state of this DebtCollectionCase.
 
-            
+            The object's current state.
 
         :return: The state of this DebtCollectionCase.
         :rtype: DebtCollectionCaseState
@@ -798,7 +798,7 @@ class DebtCollectionCase:
     def state(self, state):
         """Sets the state of this DebtCollectionCase.
 
-            
+            The object's current state.
 
         :param state: The state of this DebtCollectionCase.
         :type: DebtCollectionCaseState
@@ -810,7 +810,7 @@ class DebtCollectionCase:
     def version(self):
         """Gets the version of this DebtCollectionCase.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :return: The version of this DebtCollectionCase.
         :rtype: int
@@ -821,7 +821,7 @@ class DebtCollectionCase:
     def version(self, version):
         """Sets the version of this DebtCollectionCase.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :param version: The version of this DebtCollectionCase.
         :type: int
