@@ -124,7 +124,7 @@ class PaymentMethodConfiguration:
     def id(self):
         """Gets the id of this PaymentMethodConfiguration.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :return: The id of this PaymentMethodConfiguration.
         :rtype: int
@@ -135,7 +135,7 @@ class PaymentMethodConfiguration:
     def id(self, id):
         """Sets the id of this PaymentMethodConfiguration.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :param id: The id of this PaymentMethodConfiguration.
         :type: int
@@ -170,7 +170,7 @@ class PaymentMethodConfiguration:
     def linked_space_id(self):
         """Gets the linked_space_id of this PaymentMethodConfiguration.
 
-            The linked space id holds the ID of the space to which the entity belongs to.
+            The ID of the space this object belongs to.
 
         :return: The linked_space_id of this PaymentMethodConfiguration.
         :rtype: int
@@ -181,7 +181,7 @@ class PaymentMethodConfiguration:
     def linked_space_id(self, linked_space_id):
         """Sets the linked_space_id of this PaymentMethodConfiguration.
 
-            The linked space id holds the ID of the space to which the entity belongs to.
+            The ID of the space this object belongs to.
 
         :param linked_space_id: The linked_space_id of this PaymentMethodConfiguration.
         :type: int
@@ -264,7 +264,7 @@ class PaymentMethodConfiguration:
     def planned_purge_date(self):
         """Gets the planned_purge_date of this PaymentMethodConfiguration.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :return: The planned_purge_date of this PaymentMethodConfiguration.
         :rtype: datetime
@@ -275,7 +275,7 @@ class PaymentMethodConfiguration:
     def planned_purge_date(self, planned_purge_date):
         """Sets the planned_purge_date of this PaymentMethodConfiguration.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :param planned_purge_date: The planned_purge_date of this PaymentMethodConfiguration.
         :type: datetime
@@ -402,7 +402,7 @@ class PaymentMethodConfiguration:
     def state(self):
         """Gets the state of this PaymentMethodConfiguration.
 
-            
+            The object's current state.
 
         :return: The state of this PaymentMethodConfiguration.
         :rtype: CreationEntityState
@@ -413,7 +413,7 @@ class PaymentMethodConfiguration:
     def state(self, state):
         """Sets the state of this PaymentMethodConfiguration.
 
-            
+            The object's current state.
 
         :param state: The state of this PaymentMethodConfiguration.
         :type: CreationEntityState
@@ -448,7 +448,7 @@ class PaymentMethodConfiguration:
     def version(self):
         """Gets the version of this PaymentMethodConfiguration.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :return: The version of this PaymentMethodConfiguration.
         :rtype: int
@@ -459,7 +459,7 @@ class PaymentMethodConfiguration:
     def version(self, version):
         """Sets the version of this PaymentMethodConfiguration.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :param version: The version of this PaymentMethodConfiguration.
         :type: int
