@@ -215,7 +215,7 @@ class Refund:
     def created_on(self):
         """Gets the created_on of this Refund.
 
-            The created on date indicates the date on which the entity was stored into the database.
+            The date and time when the object was created.
 
         :return: The created_on of this Refund.
         :rtype: datetime
@@ -226,7 +226,7 @@ class Refund:
     def created_on(self, created_on):
         """Sets the created_on of this Refund.
 
-            The created on date indicates the date on which the entity was stored into the database.
+            The date and time when the object was created.
 
         :param created_on: The created_on of this Refund.
         :type: datetime
@@ -334,7 +334,7 @@ class Refund:
     def id(self):
         """Gets the id of this Refund.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :return: The id of this Refund.
         :rtype: int
@@ -345,7 +345,7 @@ class Refund:
     def id(self, id):
         """Sets the id of this Refund.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :param id: The id of this Refund.
         :type: int
@@ -380,7 +380,7 @@ class Refund:
     def language(self):
         """Gets the language of this Refund.
 
-            
+            The language that is linked to the object.
 
         :return: The language of this Refund.
         :rtype: str
@@ -391,7 +391,7 @@ class Refund:
     def language(self, language):
         """Sets the language of this Refund.
 
-            
+            The language that is linked to the object.
 
         :param language: The language of this Refund.
         :type: str
@@ -426,7 +426,7 @@ class Refund:
     def linked_space_id(self):
         """Gets the linked_space_id of this Refund.
 
-            The linked space id holds the ID of the space to which the entity belongs to.
+            The ID of the space this object belongs to.
 
         :return: The linked_space_id of this Refund.
         :rtype: int
@@ -437,7 +437,7 @@ class Refund:
     def linked_space_id(self, linked_space_id):
         """Sets the linked_space_id of this Refund.
 
-            The linked space id holds the ID of the space to which the entity belongs to.
+            The ID of the space this object belongs to.
 
         :param linked_space_id: The linked_space_id of this Refund.
         :type: int
@@ -497,7 +497,7 @@ class Refund:
     def planned_purge_date(self):
         """Gets the planned_purge_date of this Refund.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :return: The planned_purge_date of this Refund.
         :rtype: datetime
@@ -508,7 +508,7 @@ class Refund:
     def planned_purge_date(self, planned_purge_date):
         """Sets the planned_purge_date of this Refund.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :param planned_purge_date: The planned_purge_date of this Refund.
         :type: datetime
@@ -614,7 +614,7 @@ class Refund:
     def state(self):
         """Gets the state of this Refund.
 
-            
+            The object's current state.
 
         :return: The state of this Refund.
         :rtype: RefundState
@@ -625,7 +625,7 @@ class Refund:
     def state(self, state):
         """Sets the state of this Refund.
 
-            
+            The object's current state.
 
         :param state: The state of this Refund.
         :type: RefundState
@@ -844,7 +844,7 @@ class Refund:
     def version(self):
         """Gets the version of this Refund.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :return: The version of this Refund.
         :rtype: int
@@ -855,7 +855,7 @@ class Refund:
     def version(self, version):
         """Sets the version of this Refund.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :param version: The version of this Refund.
         :type: int
