@@ -12,10 +12,13 @@ class Space:
         'account': 'Account',
         'active': 'bool',
         'active_or_restricted_active': 'bool',
+        'created_by': 'int',
+        'created_on': 'datetime',
         'database': 'TenantDatabase',
         'deleted_by': 'int',
         'deleted_on': 'datetime',
         'id': 'int',
+        'last_modified_date': 'datetime',
         'name': 'str',
         'planned_purge_date': 'datetime',
         'postal_address': 'SpaceAddress',
@@ -29,17 +32,20 @@ class Space:
     }
 
     attribute_map = {
-        'account': 'account','active': 'active','active_or_restricted_active': 'activeOrRestrictedActive','database': 'database','deleted_by': 'deletedBy','deleted_on': 'deletedOn','id': 'id','name': 'name','planned_purge_date': 'plannedPurgeDate','postal_address': 'postalAddress','primary_currency': 'primaryCurrency','request_limit': 'requestLimit','restricted_active': 'restrictedActive','state': 'state','technical_contact_addresses': 'technicalContactAddresses','time_zone': 'timeZone','version': 'version',
+        'account': 'account','active': 'active','active_or_restricted_active': 'activeOrRestrictedActive','created_by': 'createdBy','created_on': 'createdOn','database': 'database','deleted_by': 'deletedBy','deleted_on': 'deletedOn','id': 'id','last_modified_date': 'lastModifiedDate','name': 'name','planned_purge_date': 'plannedPurgeDate','postal_address': 'postalAddress','primary_currency': 'primaryCurrency','request_limit': 'requestLimit','restricted_active': 'restrictedActive','state': 'state','technical_contact_addresses': 'technicalContactAddresses','time_zone': 'timeZone','version': 'version',
     }
 
     
     _account = None
     _active = None
     _active_or_restricted_active = None
+    _created_by = None
+    _created_on = None
     _database = None
     _deleted_by = None
     _deleted_on = None
     _id = None
+    _last_modified_date = None
     _name = None
     _planned_purge_date = None
     _postal_address = None
@@ -57,10 +63,13 @@ class Space:
         self.account = kwargs.get('account', None)
         self.active = kwargs.get('active', None)
         self.active_or_restricted_active = kwargs.get('active_or_restricted_active', None)
+        self.created_by = kwargs.get('created_by', None)
+        self.created_on = kwargs.get('created_on', None)
         self.database = kwargs.get('database', None)
         self.deleted_by = kwargs.get('deleted_by', None)
         self.deleted_on = kwargs.get('deleted_on', None)
         self.id = kwargs.get('id', None)
+        self.last_modified_date = kwargs.get('last_modified_date', None)
         self.name = kwargs.get('name', None)
         self.planned_purge_date = kwargs.get('planned_purge_date', None)
         self.postal_address = kwargs.get('postal_address', None)
@@ -143,6 +152,52 @@ class Space:
 
         self._active_or_restricted_active = active_or_restricted_active
     
+    @property
+    def created_by(self):
+        """Gets the created_by of this Space.
+
+            The ID of the user who created this entity.
+
+        :return: The created_by of this Space.
+        :rtype: int
+        """
+        return self._created_by
+
+    @created_by.setter
+    def created_by(self, created_by):
+        """Sets the created_by of this Space.
+
+            The ID of the user who created this entity.
+
+        :param created_by: The created_by of this Space.
+        :type: int
+        """
+
+        self._created_by = created_by
+    
+    @property
+    def created_on(self):
+        """Gets the created_on of this Space.
+
+            The date and time when this entity was created.
+
+        :return: The created_on of this Space.
+        :rtype: datetime
+        """
+        return self._created_on
+
+    @created_on.setter
+    def created_on(self, created_on):
+        """Sets the created_on of this Space.
+
+            The date and time when this entity was created.
+
+        :param created_on: The created_on of this Space.
+        :type: datetime
+        """
+
+        self._created_on = created_on
+    
     @property
     def database(self):
         """Gets the database of this Space.
@@ -216,7 +271,7 @@ class Space:
     def id(self):
         """Gets the id of this Space.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :return: The id of this Space.
         :rtype: int
@@ -227,7 +282,7 @@ class Space:
     def id(self, id):
         """Sets the id of this Space.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :param id: The id of this Space.
         :type: int
@@ -235,6 +290,29 @@ class Space:
 
         self._id = id
     
+    @property
+    def last_modified_date(self):
+        """Gets the last_modified_date of this Space.
+
+            The date and time when the object was last modified.
+
+        :return: The last_modified_date of this Space.
+        :rtype: datetime
+        """
+        return self._last_modified_date
+
+    @last_modified_date.setter
+    def last_modified_date(self, last_modified_date):
+        """Sets the last_modified_date of this Space.
+
+            The date and time when the object was last modified.
+
+        :param last_modified_date: The last_modified_date of this Space.
+        :type: datetime
+        """
+
+        self._last_modified_date = last_modified_date
+    
     @property
     def name(self):
         """Gets the name of this Space.
@@ -266,7 +344,7 @@ class Space:
     def planned_purge_date(self):
         """Gets the planned_purge_date of this Space.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :return: The planned_purge_date of this Space.
         :rtype: datetime
@@ -277,7 +355,7 @@ class Space:
     def planned_purge_date(self, planned_purge_date):
         """Sets the planned_purge_date of this Space.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :param planned_purge_date: The planned_purge_date of this Space.
         :type: datetime
@@ -381,7 +459,7 @@ class Space:
     def state(self):
         """Gets the state of this Space.
 
-            
+            The object's current state.
 
         :return: The state of this Space.
         :rtype: CreationEntityState
@@ -392,7 +470,7 @@ class Space:
     def state(self, state):
         """Sets the state of this Space.
 
-            
+            The object's current state.
 
         :param state: The state of this Space.
         :type: CreationEntityState
@@ -450,7 +528,7 @@ class Space:
     def version(self):
         """Gets the version of this Space.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :return: The version of this Space.
         :rtype: int
@@ -461,7 +539,7 @@ class Space:
     def version(self, version):
         """Sets the version of this Space.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :param version: The version of this Space.
         :type: int
