@@ -159,7 +159,7 @@ class SubscriptionCharge:
     def external_id(self):
         """Gets the external_id of this SubscriptionCharge.
 
-            The external id helps to identify the entity and a subsequent creation of an entity with the same ID will not create a new entity.
+            A client generated nonce which identifies the entity to be created. Subsequent creation requests with the same external ID will not create new entities but return the initially created entity instead.
 
         :return: The external_id of this SubscriptionCharge.
         :rtype: str
@@ -170,7 +170,7 @@ class SubscriptionCharge:
     def external_id(self, external_id):
         """Sets the external_id of this SubscriptionCharge.
 
-            The external id helps to identify the entity and a subsequent creation of an entity with the same ID will not create a new entity.
+            A client generated nonce which identifies the entity to be created. Subsequent creation requests with the same external ID will not create new entities but return the initially created entity instead.
 
         :param external_id: The external_id of this SubscriptionCharge.
         :type: str
@@ -232,7 +232,7 @@ class SubscriptionCharge:
     def id(self):
         """Gets the id of this SubscriptionCharge.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :return: The id of this SubscriptionCharge.
         :rtype: int
@@ -243,7 +243,7 @@ class SubscriptionCharge:
     def id(self, id):
         """Sets the id of this SubscriptionCharge.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :param id: The id of this SubscriptionCharge.
         :type: int
@@ -255,7 +255,7 @@ class SubscriptionCharge:
     def language(self):
         """Gets the language of this SubscriptionCharge.
 
-            
+            The language that is linked to the object.
 
         :return: The language of this SubscriptionCharge.
         :rtype: str
@@ -266,7 +266,7 @@ class SubscriptionCharge:
     def language(self, language):
         """Sets the language of this SubscriptionCharge.
 
-            
+            The language that is linked to the object.
 
         :param language: The language of this SubscriptionCharge.
         :type: str
@@ -301,7 +301,7 @@ class SubscriptionCharge:
     def linked_space_id(self):
         """Gets the linked_space_id of this SubscriptionCharge.
 
-            The linked space id holds the ID of the space to which the entity belongs to.
+            The ID of the space this object belongs to.
 
         :return: The linked_space_id of this SubscriptionCharge.
         :rtype: int
@@ -312,7 +312,7 @@ class SubscriptionCharge:
     def linked_space_id(self, linked_space_id):
         """Sets the linked_space_id of this SubscriptionCharge.
 
-            The linked space id holds the ID of the space to which the entity belongs to.
+            The ID of the space this object belongs to.
 
         :param linked_space_id: The linked_space_id of this SubscriptionCharge.
         :type: int
@@ -347,7 +347,7 @@ class SubscriptionCharge:
     def planned_purge_date(self):
         """Gets the planned_purge_date of this SubscriptionCharge.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :return: The planned_purge_date of this SubscriptionCharge.
         :rtype: datetime
@@ -358,7 +358,7 @@ class SubscriptionCharge:
     def planned_purge_date(self, planned_purge_date):
         """Sets the planned_purge_date of this SubscriptionCharge.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :param planned_purge_date: The planned_purge_date of this SubscriptionCharge.
         :type: datetime
@@ -418,7 +418,7 @@ class SubscriptionCharge:
     def state(self):
         """Gets the state of this SubscriptionCharge.
 
-            
+            The object's current state.
 
         :return: The state of this SubscriptionCharge.
         :rtype: SubscriptionChargeState
@@ -429,7 +429,7 @@ class SubscriptionCharge:
     def state(self, state):
         """Sets the state of this SubscriptionCharge.
 
-            
+            The object's current state.
 
         :param state: The state of this SubscriptionCharge.
         :type: SubscriptionChargeState
@@ -560,7 +560,7 @@ class SubscriptionCharge:
     def version(self):
         """Gets the version of this SubscriptionCharge.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :return: The version of this SubscriptionCharge.
         :rtype: int
@@ -571,7 +571,7 @@ class SubscriptionCharge:
     def version(self, version):
         """Sets the version of this SubscriptionCharge.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :param version: The version of this SubscriptionCharge.
         :type: int
