@@ -142,7 +142,7 @@ class TokenVersion:
     def created_on(self):
         """Gets the created_on of this TokenVersion.
 
-            The created on date indicates the date on which the entity was stored into the database.
+            The date and time when the object was created.
 
         :return: The created_on of this TokenVersion.
         :rtype: datetime
@@ -153,7 +153,7 @@ class TokenVersion:
     def created_on(self, created_on):
         """Sets the created_on of this TokenVersion.
 
-            The created on date indicates the date on which the entity was stored into the database.
+            The date and time when the object was created.
 
         :param created_on: The created_on of this TokenVersion.
         :type: datetime
@@ -234,7 +234,7 @@ class TokenVersion:
     def id(self):
         """Gets the id of this TokenVersion.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :return: The id of this TokenVersion.
         :rtype: int
@@ -245,7 +245,7 @@ class TokenVersion:
     def id(self, id):
         """Sets the id of this TokenVersion.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :param id: The id of this TokenVersion.
         :type: int
@@ -280,7 +280,7 @@ class TokenVersion:
     def language(self):
         """Gets the language of this TokenVersion.
 
-            
+            The language that is linked to the object.
 
         :return: The language of this TokenVersion.
         :rtype: str
@@ -291,7 +291,7 @@ class TokenVersion:
     def language(self, language):
         """Sets the language of this TokenVersion.
 
-            
+            The language that is linked to the object.
 
         :param language: The language of this TokenVersion.
         :type: str
@@ -303,7 +303,7 @@ class TokenVersion:
     def linked_space_id(self):
         """Gets the linked_space_id of this TokenVersion.
 
-            The linked space id holds the ID of the space to which the entity belongs to.
+            The ID of the space this object belongs to.
 
         :return: The linked_space_id of this TokenVersion.
         :rtype: int
@@ -314,7 +314,7 @@ class TokenVersion:
     def linked_space_id(self, linked_space_id):
         """Sets the linked_space_id of this TokenVersion.
 
-            The linked space id holds the ID of the space to which the entity belongs to.
+            The ID of the space this object belongs to.
 
         :param linked_space_id: The linked_space_id of this TokenVersion.
         :type: int
@@ -466,7 +466,7 @@ class TokenVersion:
     def planned_purge_date(self):
         """Gets the planned_purge_date of this TokenVersion.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :return: The planned_purge_date of this TokenVersion.
         :rtype: datetime
@@ -477,7 +477,7 @@ class TokenVersion:
     def planned_purge_date(self, planned_purge_date):
         """Sets the planned_purge_date of this TokenVersion.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :param planned_purge_date: The planned_purge_date of this TokenVersion.
         :type: datetime
@@ -537,7 +537,7 @@ class TokenVersion:
     def state(self):
         """Gets the state of this TokenVersion.
 
-            
+            The object's current state.
 
         :return: The state of this TokenVersion.
         :rtype: TokenVersionState
@@ -548,7 +548,7 @@ class TokenVersion:
     def state(self, state):
         """Sets the state of this TokenVersion.
 
-            
+            The object's current state.
 
         :param state: The state of this TokenVersion.
         :type: TokenVersionState
@@ -606,7 +606,7 @@ class TokenVersion:
     def version(self):
         """Gets the version of this TokenVersion.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :return: The version of this TokenVersion.
         :rtype: int
@@ -617,7 +617,7 @@ class TokenVersion:
     def version(self, version):
         """Sets the version of this TokenVersion.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :param version: The version of this TokenVersion.
         :type: int
